@@ -88,7 +88,36 @@ class CloudBuildAsyncClient:
         CloudBuildClient.parse_common_location_path
     )
 
-    from_service_account_file = CloudBuildClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudBuildAsyncClient: The constructed client.
+        """
+        return CloudBuildClient.from_service_account_info.__func__(CloudBuildAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudBuildAsyncClient: The constructed client.
+        """
+        return CloudBuildClient.from_service_account_file.__func__(CloudBuildAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
@@ -169,14 +198,14 @@ class CloudBuildAsyncClient:
         build status (such as ``SUCCESS`` or ``FAILURE``).
 
         Args:
-            request (:class:`~.cloudbuild.CreateBuildRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateBuildRequest`):
                 The request object. Request to create a new build.
             project_id (:class:`str`):
                 Required. ID of the project.
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            build (:class:`~.cloudbuild.Build`):
+            build (:class:`google.cloud.devtools.cloudbuild_v1.types.Build`):
                 Required. Build resource to create.
                 This corresponds to the ``build`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -189,33 +218,33 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloudbuild.Build``: A build resource in the
-                Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
+                build resource in the Cloud Build API.
 
-                At a high level, a ``Build`` describes where to find
-                source code, how to build it (for example, the builder
-                image to run on the source), and where to store the
-                built artifacts.
+                   At a high level, a Build describes where to find
+                   source code, how to build it (for example, the
+                   builder image to run on the source), and where to
+                   store the built artifacts.
 
-                Fields can include the following variables, which will
-                be expanded when the build is created:
+                   Fields can include the following variables, which
+                   will be expanded when the build is created:
 
-                -  $PROJECT_ID: the project ID of the build.
-                -  $BUILD_ID: the autogenerated ID of the build.
-                -  $REPO_NAME: the source repository name specified by
-                   RepoSource.
-                -  $BRANCH_NAME: the branch name specified by
-                   RepoSource.
-                -  $TAG_NAME: the tag name specified by RepoSource.
-                -  $REVISION_ID or $COMMIT_SHA: the commit SHA specified
-                   by RepoSource or resolved from the specified branch
-                   or tag.
-                -  $SHORT_SHA: first 7 characters of $REVISION_ID or
-                   $COMMIT_SHA.
+                   -  $PROJECT_ID: the project ID of the build.
+                   -  $BUILD_ID: the autogenerated ID of the build.
+                   -  $REPO_NAME: the source repository name specified
+                      by RepoSource.
+                   -  $BRANCH_NAME: the branch name specified by
+                      RepoSource.
+                   -  $TAG_NAME: the tag name specified by RepoSource.
+                   -  $REVISION_ID or $COMMIT_SHA: the commit SHA
+                      specified by RepoSource or resolved from the
+                      specified branch or tag.
+                   -  $SHORT_SHA: first 7 characters of $REVISION_ID or
+                      $COMMIT_SHA.
 
         """
         # Create or coerce a protobuf request object.
@@ -277,7 +306,7 @@ class CloudBuildAsyncClient:
         information.
 
         Args:
-            request (:class:`~.cloudbuild.GetBuildRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetBuildRequest`):
                 The request object. Request to get a build.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -297,29 +326,29 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.Build:
+            google.cloud.devtools.cloudbuild_v1.types.Build:
                 A build resource in the Cloud Build API.
 
-                At a high level, a ``Build`` describes where to find
-                source code, how to build it (for example, the builder
-                image to run on the source), and where to store the
-                built artifacts.
+                   At a high level, a Build describes where to find
+                   source code, how to build it (for example, the
+                   builder image to run on the source), and where to
+                   store the built artifacts.
 
-                Fields can include the following variables, which will
-                be expanded when the build is created:
+                   Fields can include the following variables, which
+                   will be expanded when the build is created:
 
-                -  $PROJECT_ID: the project ID of the build.
-                -  $BUILD_ID: the autogenerated ID of the build.
-                -  $REPO_NAME: the source repository name specified by
-                   RepoSource.
-                -  $BRANCH_NAME: the branch name specified by
-                   RepoSource.
-                -  $TAG_NAME: the tag name specified by RepoSource.
-                -  $REVISION_ID or $COMMIT_SHA: the commit SHA specified
-                   by RepoSource or resolved from the specified branch
-                   or tag.
-                -  $SHORT_SHA: first 7 characters of $REVISION_ID or
-                   $COMMIT_SHA.
+                   -  $PROJECT_ID: the project ID of the build.
+                   -  $BUILD_ID: the autogenerated ID of the build.
+                   -  $REPO_NAME: the source repository name specified
+                      by RepoSource.
+                   -  $BRANCH_NAME: the branch name specified by
+                      RepoSource.
+                   -  $TAG_NAME: the tag name specified by RepoSource.
+                   -  $REVISION_ID or $COMMIT_SHA: the commit SHA
+                      specified by RepoSource or resolved from the
+                      specified branch or tag.
+                   -  $SHORT_SHA: first 7 characters of $REVISION_ID or
+                      $COMMIT_SHA.
 
         """
         # Create or coerce a protobuf request object.
@@ -379,7 +408,7 @@ class CloudBuildAsyncClient:
         may have finished successfully or unsuccessfully.
 
         Args:
-            request (:class:`~.cloudbuild.ListBuildsRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListBuildsRequest`):
                 The request object. Request to list builds.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -389,6 +418,7 @@ class CloudBuildAsyncClient:
             filter (:class:`str`):
                 The raw filter text to constrain the
                 results.
+
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -400,7 +430,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListBuildsAsyncPager:
+            google.cloud.devtools.cloudbuild_v1.services.cloud_build.pagers.ListBuildsAsyncPager:
                 Response including listed builds.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -468,7 +498,7 @@ class CloudBuildAsyncClient:
         r"""Cancels a build in progress.
 
         Args:
-            request (:class:`~.cloudbuild.CancelBuildRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CancelBuildRequest`):
                 The request object. Request to cancel an ongoing build.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -488,29 +518,29 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.Build:
+            google.cloud.devtools.cloudbuild_v1.types.Build:
                 A build resource in the Cloud Build API.
 
-                At a high level, a ``Build`` describes where to find
-                source code, how to build it (for example, the builder
-                image to run on the source), and where to store the
-                built artifacts.
+                   At a high level, a Build describes where to find
+                   source code, how to build it (for example, the
+                   builder image to run on the source), and where to
+                   store the built artifacts.
 
-                Fields can include the following variables, which will
-                be expanded when the build is created:
+                   Fields can include the following variables, which
+                   will be expanded when the build is created:
 
-                -  $PROJECT_ID: the project ID of the build.
-                -  $BUILD_ID: the autogenerated ID of the build.
-                -  $REPO_NAME: the source repository name specified by
-                   RepoSource.
-                -  $BRANCH_NAME: the branch name specified by
-                   RepoSource.
-                -  $TAG_NAME: the tag name specified by RepoSource.
-                -  $REVISION_ID or $COMMIT_SHA: the commit SHA specified
-                   by RepoSource or resolved from the specified branch
-                   or tag.
-                -  $SHORT_SHA: first 7 characters of $REVISION_ID or
-                   $COMMIT_SHA.
+                   -  $PROJECT_ID: the project ID of the build.
+                   -  $BUILD_ID: the autogenerated ID of the build.
+                   -  $REPO_NAME: the source repository name specified
+                      by RepoSource.
+                   -  $BRANCH_NAME: the branch name specified by
+                      RepoSource.
+                   -  $TAG_NAME: the tag name specified by RepoSource.
+                   -  $REVISION_ID or $COMMIT_SHA: the commit SHA
+                      specified by RepoSource or resolved from the
+                      specified branch or tag.
+                   -  $SHORT_SHA: first 7 characters of $REVISION_ID or
+                      $COMMIT_SHA.
 
         """
         # Create or coerce a protobuf request object.
@@ -589,7 +619,7 @@ class CloudBuildAsyncClient:
            settings.
 
         Args:
-            request (:class:`~.cloudbuild.RetryBuildRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.RetryBuildRequest`):
                 The request object. Specifies a build to retry.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -599,6 +629,7 @@ class CloudBuildAsyncClient:
             id (:class:`str`):
                 Required. Build ID of the original
                 build.
+
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -610,33 +641,33 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloudbuild.Build``: A build resource in the
-                Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
+                build resource in the Cloud Build API.
 
-                At a high level, a ``Build`` describes where to find
-                source code, how to build it (for example, the builder
-                image to run on the source), and where to store the
-                built artifacts.
+                   At a high level, a Build describes where to find
+                   source code, how to build it (for example, the
+                   builder image to run on the source), and where to
+                   store the built artifacts.
 
-                Fields can include the following variables, which will
-                be expanded when the build is created:
+                   Fields can include the following variables, which
+                   will be expanded when the build is created:
 
-                -  $PROJECT_ID: the project ID of the build.
-                -  $BUILD_ID: the autogenerated ID of the build.
-                -  $REPO_NAME: the source repository name specified by
-                   RepoSource.
-                -  $BRANCH_NAME: the branch name specified by
-                   RepoSource.
-                -  $TAG_NAME: the tag name specified by RepoSource.
-                -  $REVISION_ID or $COMMIT_SHA: the commit SHA specified
-                   by RepoSource or resolved from the specified branch
-                   or tag.
-                -  $SHORT_SHA: first 7 characters of $REVISION_ID or
-                   $COMMIT_SHA.
+                   -  $PROJECT_ID: the project ID of the build.
+                   -  $BUILD_ID: the autogenerated ID of the build.
+                   -  $REPO_NAME: the source repository name specified
+                      by RepoSource.
+                   -  $BRANCH_NAME: the branch name specified by
+                      RepoSource.
+                   -  $TAG_NAME: the tag name specified by RepoSource.
+                   -  $REVISION_ID or $COMMIT_SHA: the commit SHA
+                      specified by RepoSource or resolved from the
+                      specified branch or tag.
+                   -  $SHORT_SHA: first 7 characters of $REVISION_ID or
+                      $COMMIT_SHA.
 
         """
         # Create or coerce a protobuf request object.
@@ -696,16 +727,17 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.CreateBuildTriggerRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateBuildTriggerRequest`):
                 The request object. Request to create a new
                 `BuildTrigger`.
             project_id (:class:`str`):
                 Required. ID of the project for which
                 to configure automatic builds.
+
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            trigger (:class:`~.cloudbuild.BuildTrigger`):
+            trigger (:class:`google.cloud.devtools.cloudbuild_v1.types.BuildTrigger`):
                 Required. ``BuildTrigger`` to create.
                 This corresponds to the ``trigger`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -718,7 +750,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.BuildTrigger:
+            google.cloud.devtools.cloudbuild_v1.types.BuildTrigger:
                 Configuration for an automated build
                 in response to source repository
                 changes.
@@ -773,18 +805,20 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.GetBuildTriggerRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetBuildTriggerRequest`):
                 The request object. Returns the `BuildTrigger` with the
                 specified ID.
             project_id (:class:`str`):
                 Required. ID of the project that owns
                 the trigger.
+
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             trigger_id (:class:`str`):
                 Required. Identifier (``id`` or ``name``) of the
                 ``BuildTrigger`` to get.
+
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -796,7 +830,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.BuildTrigger:
+            google.cloud.devtools.cloudbuild_v1.types.BuildTrigger:
                 Configuration for an automated build
                 in response to source repository
                 changes.
@@ -858,12 +892,13 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.ListBuildTriggersRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListBuildTriggersRequest`):
                 The request object. Request to list existing
                 `BuildTriggers`.
             project_id (:class:`str`):
                 Required. ID of the project for which
                 to list BuildTriggers.
+
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -875,8 +910,8 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListBuildTriggersAsyncPager:
-                Response containing existing ``BuildTriggers``.
+            google.cloud.devtools.cloudbuild_v1.services.cloud_build.pagers.ListBuildTriggersAsyncPager:
+                Response containing existing BuildTriggers.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -943,11 +978,12 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.DeleteBuildTriggerRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.DeleteBuildTriggerRequest`):
                 The request object. Request to delete a `BuildTrigger`.
             project_id (:class:`str`):
                 Required. ID of the project that owns
                 the trigger.
+
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1020,12 +1056,13 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.UpdateBuildTriggerRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.UpdateBuildTriggerRequest`):
                 The request object. Request to update an existing
                 `BuildTrigger`.
             project_id (:class:`str`):
                 Required. ID of the project that owns
                 the trigger.
+
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1034,7 +1071,7 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            trigger (:class:`~.cloudbuild.BuildTrigger`):
+            trigger (:class:`google.cloud.devtools.cloudbuild_v1.types.BuildTrigger`):
                 Required. ``BuildTrigger`` to update.
                 This corresponds to the ``trigger`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1047,7 +1084,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.BuildTrigger:
+            google.cloud.devtools.cloudbuild_v1.types.BuildTrigger:
                 Configuration for an automated build
                 in response to source repository
                 changes.
@@ -1103,7 +1140,7 @@ class CloudBuildAsyncClient:
         r"""Runs a ``BuildTrigger`` at a particular source revision.
 
         Args:
-            request (:class:`~.cloudbuild.RunBuildTriggerRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.RunBuildTriggerRequest`):
                 The request object. Specifies a build trigger to run and
                 the source to use.
             project_id (:class:`str`):
@@ -1116,9 +1153,10 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            source (:class:`~.cloudbuild.RepoSource`):
+            source (:class:`google.cloud.devtools.cloudbuild_v1.types.RepoSource`):
                 Required. Source to build against
                 this trigger.
+
                 This corresponds to the ``source`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1130,33 +1168,33 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.cloudbuild.Build``: A build resource in the
-                Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
+                build resource in the Cloud Build API.
 
-                At a high level, a ``Build`` describes where to find
-                source code, how to build it (for example, the builder
-                image to run on the source), and where to store the
-                built artifacts.
+                   At a high level, a Build describes where to find
+                   source code, how to build it (for example, the
+                   builder image to run on the source), and where to
+                   store the built artifacts.
 
-                Fields can include the following variables, which will
-                be expanded when the build is created:
+                   Fields can include the following variables, which
+                   will be expanded when the build is created:
 
-                -  $PROJECT_ID: the project ID of the build.
-                -  $BUILD_ID: the autogenerated ID of the build.
-                -  $REPO_NAME: the source repository name specified by
-                   RepoSource.
-                -  $BRANCH_NAME: the branch name specified by
-                   RepoSource.
-                -  $TAG_NAME: the tag name specified by RepoSource.
-                -  $REVISION_ID or $COMMIT_SHA: the commit SHA specified
-                   by RepoSource or resolved from the specified branch
-                   or tag.
-                -  $SHORT_SHA: first 7 characters of $REVISION_ID or
-                   $COMMIT_SHA.
+                   -  $PROJECT_ID: the project ID of the build.
+                   -  $BUILD_ID: the autogenerated ID of the build.
+                   -  $REPO_NAME: the source repository name specified
+                      by RepoSource.
+                   -  $BRANCH_NAME: the branch name specified by
+                      RepoSource.
+                   -  $TAG_NAME: the tag name specified by RepoSource.
+                   -  $REVISION_ID or $COMMIT_SHA: the commit SHA
+                      specified by RepoSource or resolved from the
+                      specified branch or tag.
+                   -  $SHORT_SHA: first 7 characters of $REVISION_ID or
+                      $COMMIT_SHA.
 
         """
         # Create or coerce a protobuf request object.
@@ -1217,7 +1255,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.CreateWorkerPoolRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateWorkerPoolRequest`):
                 The request object. Request to create a new
                 `WorkerPool`.
 
@@ -1228,7 +1266,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.WorkerPool:
+            google.cloud.devtools.cloudbuild_v1.types.WorkerPool:
                 Configuration for a WorkerPool to run
                 the builds.
                 Workers are machines that Cloud Build
@@ -1274,7 +1312,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.GetWorkerPoolRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetWorkerPoolRequest`):
                 The request object. Request to get a `WorkerPool` with
                 the specified name.
 
@@ -1285,7 +1323,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.WorkerPool:
+            google.cloud.devtools.cloudbuild_v1.types.WorkerPool:
                 Configuration for a WorkerPool to run
                 the builds.
                 Workers are machines that Cloud Build
@@ -1339,7 +1377,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.DeleteWorkerPoolRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.DeleteWorkerPoolRequest`):
                 The request object. Request to delete a `WorkerPool`.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1378,7 +1416,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.UpdateWorkerPoolRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.UpdateWorkerPoolRequest`):
                 The request object. Request to update a `WorkerPool`.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1388,7 +1426,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.WorkerPool:
+            google.cloud.devtools.cloudbuild_v1.types.WorkerPool:
                 Configuration for a WorkerPool to run
                 the builds.
                 Workers are machines that Cloud Build
@@ -1434,7 +1472,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`~.cloudbuild.ListWorkerPoolsRequest`):
+            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsRequest`):
                 The request object. Request to list `WorkerPools`.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1444,8 +1482,8 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloudbuild.ListWorkerPoolsResponse:
-                Response containing existing ``WorkerPools``.
+            google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsResponse:
+                Response containing existing WorkerPools.
         """
         # Create or coerce a protobuf request object.
 
